@@ -63,7 +63,9 @@ defaultRequester = DataFileRequester(
 )
 
 
-def retrieveBoilerplateFile(doc, name, group=None, status=None, error=True, allowLocal=True):
+def retrieveBoilerplateFile(
+    doc, name, group=None, status=None, error=True, allowLocal=True
+):
     # Looks in three or four locations, in order:
     # the folder the spec source is in, the group's boilerplate folder, the megagroup's boilerplate folder, and the generic boilerplate folder.
     # In each location, it first looks for the file specialized on status, and then for the generic file.
@@ -104,8 +106,12 @@ def retrieveBoilerplateFile(doc, name, group=None, status=None, error=True, allo
         sources.append(InputSource(boilerplatePath(group, statusFile), chroot=False))
         sources.append(InputSource(boilerplatePath(group, genericFile), chroot=False))
     if megaGroup:
-        sources.append(InputSource(boilerplatePath(megaGroup, statusFile), chroot=False))
-        sources.append(InputSource(boilerplatePath(megaGroup, genericFile), chroot=False))
+        sources.append(
+            InputSource(boilerplatePath(megaGroup, statusFile), chroot=False)
+        )
+        sources.append(
+            InputSource(boilerplatePath(megaGroup, genericFile), chroot=False)
+        )
     sources.append(InputSource(boilerplatePath(statusFile), chroot=False))
     sources.append(InputSource(boilerplatePath(genericFile), chroot=False))
 
